@@ -1,7 +1,9 @@
 import numpy as np
 import csv
+import sqlalchemy
+from sqlalchemy.engine import URL
 
-__version__ = '0.0.1'
+__version__ = '1.0.3'
 
 class DataFrame:
 
@@ -1088,12 +1090,10 @@ class StringMethods:
 def read_csv(file,header=0):
     """
     Read a simple comma-separated-value(CSV) file as a DataFrame
-
     Parameters
     ----------
     file: str of file location
     header: index value of header 
-
     Returns
     -------
     A DataFrame
@@ -1128,7 +1128,6 @@ def read_csv(file,header=0):
                 values = line.strip('\n').split(',')
                 for col, val in zip(column_names, values):
                     data[col].append(val)
-    # return data
     new_data = {}
     # vals is a list of strings
     for col, vals in data.items():
@@ -1139,4 +1138,51 @@ def read_csv(file,header=0):
                 new_data[col] = np.array(vals, dtype='float')
             except ValueError:
                 new_data[col] = np.array(vals, dtype='O')
-    return DataFrame(new_data)
\ No newline at end of file
+    return DataFrame(new_data)
+
+
+def read_sql(sql,drivername,username,password,host,port,database):
+    """
+    Read a sql table based on sql query as a DataFrame
+
+    Parameters
+    ----------
+    sql: str of sql query to be executed
+    drivername: str of driver engine of the database
+    username: str of username to connect to the database
+    password: str of password to connect to the database
+    host: str of host to connect to the database
+    port: int of port to connect to the database
+    database: str of database name  
+
+    Returns
+    -------
+    A DataFrame
+    """
+    from collections import defaultdict
+    data = defaultdict(list)
+    db_engine = URL.create(drivername,username,password,host,port,database) 
+    conn = sqlalchemy.create_engine(db_engine) 
+    with conn.connect() as con:
+        rs = con.execute(sql)
+        #get column names
+        columns = []
+        for elem in rs.cursor.description:
+            columns.append(elem[0])
+        #key,value mapping
+        for record in rs:
+            for col,val in zip(columns,record):
+                data[col].append(val)
+
+    new_data = {}
+    # vals is a list of strings
+    for col, vals in data.items():
+        try:
+            new_data[col] = np.array(vals, dtype='int')
+        except ValueError:
+            try:
+                new_data[col] = np.array(vals, dtype='float')
+            except ValueError:
+                new_data[col] = np.array(vals, dtype='O')
+    return DataFrame(new_data)
+
