@@ -1,5 +1,9 @@
 import numpy as np
 from numpy.testing import assert_array_equal
+from sqlalchemy import create_engine, Column, Integer, String, DateTime
+from sqlalchemy.orm import declarative_base, sessionmaker
+from sqlalchemy.engine import URL
+from datetime import datetime
 import pytest
 
 import ickle as ick
@@ -806,39 +810,85 @@ class TestStrings:
         answer = ick.DataFrame({'movie': movie})
         assert_df_equals(result, answer)
 
-
-df_emp = ick.read_csv('dataset/employee.csv')
-
+df_emp = ick.read_csv(file='dataset/employee.csv', header=None)
 
 class TestReadCSV:
 
     def test_columns(self):
         result = df_emp.columns
-        answer = ['dept', 'race', 'gender', 'salary']
+        answer = ['0', '1', '2', '3']
         assert result == answer
 
     def test_data_types(self):
         df_result = df_emp.dtypes
-        cols = np.array(['dept', 'race', 'gender', 'salary'], dtype='O')
+        cols = np.array(['0', '1', '2', '3'], dtype='O')
         dtypes = np.array(['string', 'string', 'string', 'int'], dtype='O')
         df_answer = ick.DataFrame({'Column Name': cols,
                                    'Data Type': dtypes})
         assert_df_equals(df_result, df_answer)
 
     def test_sum(self):
-        result = df_emp['salary'].sum()
+        result = df_emp['3'].sum()
         answer = 86387875
         assert result == answer
 
     def test_head(self):
-        data = {'dept': np.array(['Houston Police Department-HPD',
+        data = {'0': np.array(['Houston Police Department-HPD',
                                   'Houston Fire Department (HFD)',
                                   'Houston Police Department-HPD',
                                   'Public Works & Engineering-PWE',
                                   'Houston Airport System (HAS)'], dtype='O'),
-                'race': np.array(['White', 'White', 'Black', 'Asian', 'White'], dtype='O'),
-                'gender': np.array(['Male', 'Male', 'Male', 'Male', 'Male'], dtype='O'),
-                'salary': np.array([45279, 63166, 66614, 71680, 42390])}
+                '1': np.array(['White', 'White', 'Black', 'Asian', 'White'], dtype='O'),
+                '2': np.array(['Male', 'Male', 'Male', 'Male', 'Male'], dtype='O'),
+                '3': np.array([45279, 63166, 66614, 71680, 42390])}
         result = df_emp.head()
         answer = ick.DataFrame(data)
-        assert_df_equals(result, answer)
\ No newline at end of file
+        assert_df_equals(result, answer)
+
+Base = declarative_base()
+
+class Author(Base):
+    __tablename__ = 'authors'
+    id = Column(Integer(), primary_key=True)
+    firstname = Column(String(100))
+    lastname = Column(String(100))
+    email = Column(String(255), nullable=False)
+    joined = Column(DateTime(), default=datetime.now)
+
+url = URL.create(
+        drivername="postgresql",
+        username="postgres",
+        password="pri123",
+        host="localhost",
+        port="5432",
+        database="spotify_trends"
+)  
+engine = create_engine(url)
+Session = sessionmaker(bind=engine)
+
+@pytest.fixture(scope='module')
+def db_session():
+    Base.metadata.create_all(engine)
+    session = Session()
+    yield session
+    session.rollback()
+    session.close()
+
+@pytest.fixture(scope='module')
+def valid_author():
+    valid_author = Author(
+        firstname="John",
+        lastname="Doe",
+        email="upchh@example.com"
+    )
+    return valid_author
+
+class TestSqlDataframe:
+    def test_sql_dataframe(self, db_session, valid_author):
+        db_session.add(valid_author)
+        db_session.commit()
+        sql = 'SELECT id, firstname, lastname, email FROM authors'
+        df = ick.read_sql(sql,url)
+        assert df["firstname"] == "John"
+        assert df["lastname"] == "Doe"
+        assert df["email"] == "upchh@example.com"
\ No newline at end of file
